apply_reynolds_correction

Function apply_reynolds_correction 

pub fn apply_reynolds_correction(
    base_cd: f64,
    velocity_mps: f64,
    diameter_inches: f64,
    air_density_kg_m3: f64,
    temperature_c: f64,
    mach: f64,
) -> f64
Apply the low-Re correction to a drag coefficient (convenience function).

Coefficients from standard projectile drag tables are unchanged for ordinary ballistic Reynolds numbers (Re >= 10,000) because those empirical tables already include their measured Reynolds-number dependence.

Arguments

  • base_cd - Base drag coefficient from G1/G7 model
  • velocity_mps - Velocity in meters per second
  • diameter_inches - Bullet diameter in inches
  • air_density_kg_m3 - Air density in kg/m³
  • temperature_c - Temperature in Celsius
  • mach - Mach number

Returns

Corrected drag coefficient